import json

from django.contrib.gis.geos import Point
from django.db.models import Q

from .models import EcologicalRegion, EcologicalDistrictLayer, SoilOrder


def coordinate_filter(request, queryset):
    coordinates = request.query_params.get('coordinates')

    if coordinates is not None:
        coordinates_json = json.loads(coordinates)
        pnt = Point(coordinates_json["lng"],
                    coordinates_json["lat"], srid=4326)
        pnt.transform(2193)

        filtered_regions = EcologicalRegion.objects.filter(
            ecologicaldistrictlayer__geom__intersects=pnt).values_list('id', flat=True)
        filtered_soil_orders = SoilOrder.objects.filter(
            soillayer__geom__intersects=pnt).values_list('id', flat=True)

        # Filter by ecological regions and soil orders
        return queryset.filter(
            Q(ecological_regions__in=filtered_regions) &
            Q(soil_order__in=filtered_soil_orders))

    return queryset
